@@ -48,14 +48,18 @@
 #' carseats <- ISLR::Carseats
 #' carseats[sample(seq(NROW(carseats)), 20), "Income"] <- NA
 #' carseats[sample(seq(NROW(carseats)), 5), "Urban"] <- NA
+#' 
 #' # Binning the carat variable. default type argument is "quantile"
 #' bin <- binning(carseats$Income)
 #' # Print bins class object
 #' bin
+#' 
 #' # Summarise bins class object
 #' summary(bin)
+#' 
 #' # Plot bins class object
 #' plot(bin)
+#' 
 #' # Using labels argument
 #' bin <- binning(carseats$Income, nbins = 4,
 #'               labels = c("LQ1", "UQ1", "LQ3", "UQ3"))
@@ -359,9 +363,13 @@ plot.bins <- function(x, typographic = TRUE, ...) {
   
   if (typographic) {
     p_bottom <- p_bottom +
-      theme_typographic() 
+      theme_typographic() +
+      theme(plot.margin = margin(5, 20, 10, 20))
   }
   
+  p_bottom <- p_bottom +
+    theme(axis.text.x = element_text(angle = 45, hjust = 1))
+  
   suppressWarnings(gridExtra::grid.arrange(p_top, p_bottom, nrow = 2, ncol = 1)) 
 }
 
@@ -859,7 +867,10 @@ extract.bins <- function(x) {
   idx <- as.integer(object)
   levels <- attr(object,"levels")
   
-  factor(levels[idx], levels = levels)
+  raw <- factor(levels[idx], levels = levels)
+  class(raw) <- class(x)[-1]
+  
+  raw
 }
 
 
